import { XRProvider, XROptions, SceneOptions } from './types';
export declare class XRClass {
    private _options;
    private _pluggables;
    private _defaultProvider;
    /**
     * Initialize XR with AWS configurations
     *
     * @param {XROptions} options - Configuration object for XR
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    constructor(options: XROptions);
    /**
     * Configure XR part with configurations
     *
     * @param {XROptions} config - Configuration for XR
     * @return {Object} - The current configuration
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    configure(options: XROptions): XROptions;
    /**
     * add plugin into XR category
     * @param {Object} pluggable - an instance of the plugin
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    addPluggable(pluggable: XRProvider): Promise<object>;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    loadScene(sceneName: string, domElementId: string, sceneOptions?: SceneOptions, provider?: string): Promise<any>;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    isSceneLoaded(sceneName: string, provider?: string): boolean;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    getSceneController(sceneName: string, provider?: string): any;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    isVRCapable(sceneName: string, provider?: string): boolean;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    isVRPresentationActive(sceneName: string, provider?: string): boolean;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    start(sceneName: string, provider?: string): void;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    enterVR(sceneName: string, provider?: string): void;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    exitVR(sceneName: string, provider?: string): void;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    isMuted(sceneName: string, provider?: string): boolean;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    setMuted(sceneName: string, muted: boolean, provider?: string): void;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    onSceneEvent(sceneName: string, eventName: string, eventHandler: Function, provider?: string): void;
    /**
     * @deprecated The XR category depends on Amazon Sumerian to function. Amazon Sumerian scenes will not be accessible
     * as of February 21, 2023. Follow the documentation on this page
     * https://docs.amplify.aws/lib/xr/getting-started/q/platform/js/ to learn more about your migration options.
     */
    enableAudio(sceneName: string, provider?: string): void;
}
export declare const XR: XRClass;
